import {gql} from '../helpers'
import {   
   actionPromise, 
   actionAuthLogin, 
   actionAboutMe
} from '../reducers'
import {   
   actionUploadFile
} from './mediaActions'


 
   const actionLogin = (login, password) => (
      actionPromise('login', gql(`query log($login: String, $password: String) {
         login(login: $login, password: $password)
      }`, {login, password}))
   )

   export const actionFullLogin = (login, password) => (
      async (dispatch) => {
         let token = await dispatch(actionLogin(login, password))
         if (token) {
            await dispatch(actionAuthLogin(token))
            await dispatch(actionAboutMe())
         }
      }
   )
   
   const actionRegister = (login, password, nick) => (
      actionPromise('register', gql(`mutation reg($user:UserInput) {
         UserUpsert(user:$user) {
         _id 
         }
      }
      `, {user: {login, password, nick}})      
      )
   )

   export const actionFullRegister = (login, password) => (
      async (dispatch) => {
         let regId = await dispatch(actionRegister(login, password))
         if (regId) {
            await dispatch(actionFullLogin(login, password))
         }
      }
   )


   export const actionChangeUser = (userId, nick, login ) => (
      actionPromise('changeUser', gql(`mutation changeUser($user: UserInput) {
         UserUpsert (user: $user) {
            _id
            createdAt
            login
            nick
            avatar {
               url
            }
         }
      }`, { user: {_id: userId, nick, login}  }
      ))
   )

   export const actionRemoveUser = (userId) => (
      actionPromise('changeUser', gql(`mutation changeUser($user: UserInput) {
         UserDelete (user: $user){
           _id
         }     
      }`, { user: { _id: userId }  }
      ))
   )





   // export const actionChangePass = (login, password, newPassword) => (
   //    actionPromise('changePass', gql(`mutation change($login: String! $password: String! $newPassword: String!) {
   //       UserUpsert(user: {login: $login, password: $password, newPassword: $newPassword}) {
   //          _id
   //          login
   //        }
   //    }
   //    `, {login, password, newPassword})      
   //    )
   // )
   // // changePassword( login: String! password: String! newPassword: String! ): User






   const actionUpdateUser = (userId, avatarId, newLogin, newNick, newChats) => (
      actionPromise('updateUser', gql(`mutation updateUser($user:UserInput) {
         UserUpsert(user:$user) {
            _id   
            login  
            nick
         }
      }`, { user: {_id: userId, avatar: {_id: avatarId} } }))
   )

      // имеет сомнительную пользу, так как позволяет обновить только аву, 
      // ниже метод обновляющий также логин и ник в форме
   export const actionSetAvatar = (name, file) => (
      async (dispatch, getState) => {
         let fileObj = await dispatch(actionUploadFile(name, file))
         console.log(fileObj._id)
         let {auth} = getState()
         let userId = auth?.payload?.sub?.id 

         await dispatch(actionUpdateUser(userId, fileObj._id))

         await dispatch(actionAboutMe())    
      }
   )

   export const actionSetUserInfo = (name, file, newLogin, newNick) => (
      async (dispatch, getState) => {
         let fileObj = await dispatch(actionUploadFile(name, file))
         let {auth} = getState()
         let userId = auth?.payload?.sub?.id 

         await dispatch(actionUpdateUser(userId, fileObj._id, newLogin, newNick))

         await dispatch(actionAboutMe())    
      }
   )


      // !!!! ПОДХОД ВЕРНЫЙ ТОЛЬКО ДЛЯ ЗАГРУЗКИ МНОГИХ ФАЙЛОВ В СООБЩЕНИЕ
   // позволяет загрузить файл и взамен получить url  
   // нужен для предпросмотра, когда юзер еще не определился нужно ли добавлять этот url в стейт
   export const actionGroupFiles = (name, file) => (
      async (dispatch, getState) => {
         let fileObj = await dispatch(actionUploadFile(name, file))
         let URL = fileObj.avatar.url
         console.log(fileObj._id)
         let {auth} = getState()
         let userId = auth?.payload?.sub?.id 

         await dispatch(actionUpdateUser(userId, fileObj._id))

         await dispatch(actionAboutMe())    
      }
   )


   // так же нужен setUserChats